@@ -11,7 +11,10 @@ sort of hotplug.  Instead it generates a topological order and loads
 everything.  The idea is to require very few modules.
 """
 
+from typing import List
+
 import re
+import shutil
 import subprocess
 import os, os.path
 import itertools
@@ -19,7 +22,9 @@ import itertools
 _INSMOD_RE = re.compile('insmod (.*[^ ]) *$')
 
 def resolve_dep(modalias, root=None, kver=None, moddir=None):
-    args = ['modprobe', '--show-depends']
+    # /usr/sbin might not be in the path, and modprobe is usually in /usr/sbin
+    modprobe = shutil.which('modprobe') or '/usr/sbin/modprobe'
+    args = [modprobe, '--show-depends']
     args += ['-C', '/var/empty']
     if root is not None:
         args += ['-d', root]
@@ -46,8 +51,8 @@ def resolve_dep(modalias, root=None, kver=None, moddir=None):
 
     return deps
 
-def merge_mods(lists):
-    found = set()
+def merge_mods(lists) -> List[str]:
+    found: set = set()
     mods = []
     for mod in itertools.chain(*lists):
         if mod not in found:
